@@ -1,3 +1,5 @@
+from aryth.structs import Leap
+
 from palett.projector.utils.parse_hsl import parse_hsl
 
 
@@ -11,7 +13,8 @@ def preset_to_leap(preset):
 def color_bound(max_hsl, min_hsl):
     max_h, max_s, max_l = max_hsl
     min_h, min_s, min_l = min_hsl
-    return {
-        'min': (min_h, min_s, min_l),
-        'dif': (max_h - min_h, max_s - min_s, max_l - min_l)
-    }
+    return Leap(
+        min=min_hsl,
+        dif=(max_h - min_h, max_s - min_s, max_l - min_l),
+        max=max_hsl
+    )
